
## CATO-CLI - mutation.policy.remotePortFwd.discardPolicyRevision:
[Click here](https://api.catonetworks.com/documentation/#mutation-discardPolicyRevision) for documentation on this operation.

### Usage for mutation.policy.remotePortFwd.discardPolicyRevision:

`catocli mutation policy remotePortFwd discardPolicyRevision -h`

`catocli mutation policy remotePortFwd discardPolicyRevision <json>`

`catocli mutation policy remotePortFwd discardPolicyRevision "$(cat < discardPolicyRevision.json)"`

`catocli mutation policy remotePortFwd discardPolicyRevision '{"policyDiscardRevisionInput": {"id": {"id": "ID"}}, "remotePortFwdPolicyMutationInput": {"policyMutationRevisionInput": {"id": {"id": "ID"}}}}'`

#### Operation Arguments for mutation.policy.remotePortFwd.discardPolicyRevision ####
`accountId` [ID] - (required) N/A 
`policyDiscardRevisionInput` [PolicyDiscardRevisionInput] - (optional) N/A 
`remotePortFwdPolicyMutationInput` [RemotePortFwdPolicyMutationInput] - (optional) N/A 
